@@ -228,7 +228,7 @@ class CloudRunJob(Infrastructure):
         description=(
             "The image to use for a new Cloud Run Job. This value must "
             "refer to an image within either Google Container Registry "
-            "or Google Artifact Registry."
+            "or Google Artifact Registry, like `gcr.io/<project_name>/<repo>/`"
         ),
     )
     region: str = Field(..., description="The region where the Cloud Run Job resides.")
@@ -318,22 +318,14 @@ class CloudRunJob(Infrastructure):
         if value is not None:
             return value.strip()
 
-    @validator("cpu")
-    def _convert_cpu_to_k8s_quantity(cls, value):
-        """Set CPU integer to the format expected by API.
-        See: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
-        See also: https://cloud.google.com/run/docs/configuring/cpu#setting-jobs
-        """  # noqa
-        return str(value * 1000) + "m"
-
     @root_validator
     def _check_valid_memory(cls, values):
         """Make sure memory conforms to expected values for API.
         See: https://cloud.google.com/run/docs/configuring/memory-limits#setting
         """  # noqa
-        if (
-            values.get("memory") is not None and values.get("memory_units") is None
-        ) or (values.get("memory_units") is not None and values.get("memory") is None):
+        if (values.get("memory") is not None and values.get("memory_unit") is None) or (
+            values.get("memory_unit") is not None and values.get("memory") is None
+        ):
             raise ValueError(
                 "A memory value and unit must both be supplied to specify a memory"
                 " value other than the default memory value."
@@ -377,6 +369,13 @@ class CloudRunJob(Infrastructure):
 
         raise exc
 
+    def _cpu_as_k8s_quantity(self) -> str:
+        """Return the CPU integer in the format expected by GCP Cloud Run Jobs API.
+        See: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
+        See also: https://cloud.google.com/run/docs/configuring/cpu#setting-jobs
+        """  # noqa
+        return str(self.cpu * 1000) + "m"
+
     @sync_compatible
     async def run(self, task_status: Optional[TaskStatus] = None):
         """Run the configured job on a Google Cloud Run Job."""
@@ -664,8 +663,9 @@ class CloudRunJob(Infrastructure):
         resources = {"limits": {}, "requests": {}}
 
         if self.cpu is not None:
-            resources["limits"]["cpu"] = self.cpu
-            resources["requests"]["cpu"] = self.cpu
+            cpu = self._cpu_as_k8s_quantity()
+            resources["limits"]["cpu"] = cpu
+            resources["requests"]["cpu"] = cpu
         if self.memory_string is not None:
             resources["limits"]["memory"] = self.memory_string
             resources["requests"]["memory"] = self.memory_string
