@@ -120,13 +120,14 @@ async def cloud_storage_download_blob_as_bytes(
         ```python
         from prefect import flow
         from prefect_gcp import GcpCredentials
-        from prefect_gcp.cloud_storage import cloud_storage_download_blob
+        from prefect_gcp.cloud_storage import cloud_storage_download_blob_as_bytes
 
         @flow()
         def example_cloud_storage_download_blob_flow():
             gcp_credentials = GcpCredentials(
                 service_account_file="/path/to/service/account/keyfile.json")
-            contents = cloud_storage_download_blob("bucket", "blob", gcp_credentials)
+            contents = cloud_storage_download_blob_as_bytes(
+                "bucket", "blob", gcp_credentials)
             return contents
 
         example_cloud_storage_download_blob_flow()
@@ -187,14 +188,14 @@ async def cloud_storage_download_blob_to_file(
         ```python
         from prefect import flow
         from prefect_gcp import GcpCredentials
-        from prefect_gcp.cloud_storage import cloud_storage_download_blob
+        from prefect_gcp.cloud_storage import cloud_storage_download_blob_to_file
 
         @flow()
         def example_cloud_storage_download_blob_flow():
             gcp_credentials = GcpCredentials(
                 service_account_file="/path/to/service/account/keyfile.json")
-            path = cloud_storage_download_blob(
-                "bucket", "blob", "data_path", gcp_credentials)
+            path = cloud_storage_download_blob_to_file(
+                "bucket", "blob", "file_path", gcp_credentials)
             return path
 
         example_cloud_storage_download_blob_flow()
@@ -336,7 +337,7 @@ async def cloud_storage_upload_blob_from_file(
 
     Example:
         Uploads blob to bucket.
-        ```
+        ```python
         from prefect import flow
         from prefect_gcp import GcpCredentials
         from prefect_gcp.cloud_storage import cloud_storage_upload_blob_from_file
